@@ -11,6 +11,13 @@ fn main() {
     // the rustc version.
     println!("cargo:rerun-if-changed=build.rs");
 
+    use_feature_or_nothing("vec_into_raw_parts");
+    use_feature_or_nothing("toowned_clone_into");
+    use_feature_or_nothing("rustc_attrs");
+    use_feature_or_nothing("specialization");
+    use_feature_or_nothing("slice_internals");
+    use_feature_or_nothing("const_raw_ptr_deref");
+
     let arch = var("CARGO_CFG_TARGET_ARCH").unwrap();
     let asm_name = format!("{}/{}.S", OUTLINE_PATH, arch);
     let os_name = var("CARGO_CFG_TARGET_OS").unwrap();
@@ -28,7 +35,6 @@ fn main() {
     } else {
         use_feature("linux_raw");
 
-        use_feature_or_nothing("rustc_attrs");
         use_feature_or_nothing("core_intrinsics");
         use_feature_or_nothing("doc_cfg");
 
@@ -60,25 +66,27 @@ fn link_in_librustix_outline(arch: &str, asm_name: &str) {
         let out_dir = var("OUT_DIR").unwrap();
         Build::new().file(&asm_name).compile(&name);
         println!("cargo:rerun-if-changed={}", asm_name);
-        let from = format!("{}/lib{}.a", out_dir, name);
-        let prev_metadata = std::fs::metadata(&to);
-        std::fs::copy(&from, &to).unwrap();
-        assert!(
-            prev_metadata.is_ok(),
-            "{} didn't previously exist; please inspect the new file and `git add` it",
-            to
-        );
-        assert!(
-            std::process::Command::new("git")
-                .arg("diff")
-                .arg("--quiet")
-                .arg(&to)
-                .status()
-                .unwrap()
-                .success(),
-            "{} changed; please inspect the change and `git commit` it",
-            to
-        );
+        if std::fs::metadata(".git").is_ok() {
+            let from = format!("{}/lib{}.a", out_dir, name);
+            let prev_metadata = std::fs::metadata(&to);
+            std::fs::copy(&from, &to).unwrap();
+            assert!(
+                prev_metadata.is_ok(),
+                "{} didn't previously exist; please inspect the new file and `git add` it",
+                to
+            );
+            assert!(
+                std::process::Command::new("git")
+                    .arg("diff")
+                    .arg("--quiet")
+                    .arg(&to)
+                    .status()
+                    .unwrap()
+                    .success(),
+                "{} changed; please inspect the change and `git commit` it",
+                to
+            );
+        }
     }
 }
 
